@@ -126,6 +126,8 @@ pub mod inbox_ruleset_test_result;
 pub use self::inbox_ruleset_test_result::InboxRulesetTestResult;
 pub mod ip_address_result;
 pub use self::ip_address_result::IpAddressResult;
+pub mod json_schema_dto;
+pub use self::json_schema_dto::JsonSchemaDto;
 pub mod match_option;
 pub use self::match_option::MatchOption;
 pub mod match_options;
